# Chat
The Chat feature is an interactive interface that enables users to communicate with a selected agent in a conversational manner. Users can type messages and send them to the agent, which will then generate responses based on its configuration and training. The Chat feature also offers an optional Smart Chat functionality, which aims to optimize the agent's responses by considering the context and taking into account previous messages in the conversation.

## Smart Chat
Smart Chat will take your request, do research online to find the most up to date information about what you asked it so that it has information in memory. It will then use this information to complete the task you asked it to do along with executing any commands necessary along the way.